==> haskell-word-wrap-0.5-194-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-word-wrap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 word-wrap
version:              0.5
visibility:           public
id:                   word-wrap-0.5-DXMEcpb3fSkLBynYecHCcY
key:                  word-wrap-0.5-DXMEcpb3fSkLBynYecHCcY
license:              BSD-3-Clause
copyright:            2017 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
homepage:             https://github.com/jtdaugherty/word-wrap/
synopsis:             A library for word-wrapping
description:          A library for wrapping long lines of text.
category:             Text
abi:                  51c4a68f0ccfd40a27bee10cf94445b0
exposed:              True
exposed-modules:      Text.Wrap
import-dirs:          /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-word-wrap
hs-libraries:         HSword-wrap-0.5-DXMEcpb3fSkLBynYecHCcY
depends:              base-4.18.2.1 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-word-wrap/html/word-wrap.haddock
haddock-html:         /usr/share/doc/haskell-word-wrap/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-word-wrap-0.5-195-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-word-wrap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 word-wrap
version:              0.5
visibility:           public
id:                   word-wrap-0.5-IC0TyYODHEjBcngJaGFivc
key:                  word-wrap-0.5-IC0TyYODHEjBcngJaGFivc
license:              BSD-3-Clause
copyright:            2017 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
homepage:             https://github.com/jtdaugherty/word-wrap/
synopsis:             A library for word-wrapping
description:          A library for wrapping long lines of text.
category:             Text
abi:                  eb7c1d53300857b99dfda0966ba1af88
exposed:              True
exposed-modules:      Text.Wrap
import-dirs:          /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-word-wrap
hs-libraries:         HSword-wrap-0.5-IC0TyYODHEjBcngJaGFivc
depends:              base-4.18.2.1 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-word-wrap/html/word-wrap.haddock
haddock-html:         /usr/share/doc/haskell-word-wrap/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
